@@ -22,8 +22,8 @@
 #include "ircinput.h"
 #include "ircviewbox.h"
 #include "ircview.h"
-#include <kabc/addressbook.h>
-#include <kabc/stdaddressbook.h>
+#include <tdeabc/addressbook.h>
+#include <tdeabc/stdaddressbook.h>
 #include "common.h"
 #include "topiclabel.h"
 #include "channeloptionsdialog.h"
@@ -56,13 +56,13 @@
 #include <klineedit.h>
 #include <kinputdialog.h>
 #include <kpassdlg.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kglobalsettings.h>
-#include <kdeversion.h>
-#include <kmessagebox.h>
+#include <tdeglobalsettings.h>
+#include <tdeversion.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
-#include <kwin.h>
+#include <twin.h>
 
 
 Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
@@ -115,7 +115,7 @@ Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
     TQSizePolicy greedy = TQSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
 
     m_vertSplitter = new TQSplitter(Qt::Vertical, this);
-    m_vertSplitter->setOpaqueResize(KGlobalSettings::opaqueResize());
+    m_vertSplitter->setOpaqueResize(TDEGlobalSettings::opaqueResize());
 
 
     TQWidget* topicWidget = new TQWidget(m_vertSplitter);
@@ -182,7 +182,7 @@ Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
 
     // (this) The main Box, holding the channel view/topic and the input line
     m_horizSplitter = new TQSplitter(m_vertSplitter);
-    m_horizSplitter->setOpaqueResize( KGlobalSettings::opaqueResize() );
+    m_horizSplitter->setOpaqueResize( TDEGlobalSettings::opaqueResize() );
 
     // Server will be set later in setServer()
     IRCViewBox* ircViewBox = new IRCViewBox(m_horizSplitter, NULL);
@@ -197,17 +197,17 @@ Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
 
     nicknameListView=new NickListView(nickListButtons, this);
     nicknameListView->setHScrollBarMode(TQScrollView::AlwaysOff);
-    nicknameListView->setSelectionModeExt(KListView::Extended);
+    nicknameListView->setSelectionModeExt(TDEListView::Extended);
     nicknameListView->setAllColumnsShowFocus(true);
     nicknameListView->setSorting(1,true);
     nicknameListView->addColumn(TQString());
     nicknameListView->addColumn(TQString());
-    nicknameListView->setColumnWidthMode(1,KListView::Maximum);
+    nicknameListView->setColumnWidthMode(1,TDEListView::Maximum);
 
     nicknameListView->header()->hide();
 
     // setResizeMode must be called after all the columns are added
-    nicknameListView->setResizeMode(KListView::LastColumn);
+    nicknameListView->setResizeMode(TDEListView::LastColumn);
 
     // separate LED from Text a little more
     nicknameListView->setColumnWidth(0, 10);
@@ -232,7 +232,7 @@ Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
     awayLabel->hide();
     blowfishLabel = new TQLabel(commandLineBox);
     blowfishLabel->hide();
-    blowfishLabel->setPixmap(KGlobal::iconLoader()->loadIcon("encrypted", KIcon::Toolbar));
+    blowfishLabel->setPixmap(TDEGlobal::iconLoader()->loadIcon("encrypted", TDEIcon::Toolbar));
     channelInput = new IRCInput(commandLineBox);
 
     getTextView()->installEventFilter(channelInput);
@@ -489,13 +489,13 @@ void Channel::popupCommand(int id)
                 {
                     if(id == Konversation::AddressbookDelete)
                     {
-                        KABC::Addressee addr = (*it)->getNickInfo()->getAddressee();
+                        TDEABC::Addressee addr = (*it)->getNickInfo()->getAddressee();
                         addressbook->unassociateNick(addr, (*it)->getNickname(), m_server->getServerName(), m_server->getDisplayName());
                     }
                     else
                     {
                         //make new addressbook contact
-                        KABC::Addressee addr;
+                        TDEABC::Addressee addr;
                         NickInfoPtr nickInfo = (*it)->getNickInfo();
                         if(nickInfo->getRealName().isEmpty())
                             addr.setGivenName(nickInfo->getNickname());
@@ -2255,7 +2255,7 @@ void Channel::updateAppearance()
     {
         fg=colorGroup().foreground();
         bg=colorGroup().base();
-        abg=KGlobalSettings::alternateBackgroundColor();
+        abg=TDEGlobalSettings::alternateBackgroundColor();
     }
 
     channelInput->unsetPalette();
@@ -2289,11 +2289,11 @@ void Channel::updateAppearance()
     }
     else
     {
-        getTextView()->setFont(KGlobalSettings::generalFont());
-        topicLine->setFont(KGlobalSettings::generalFont());
-        channelInput->setFont(KGlobalSettings::generalFont());
-        nicknameCombobox->setFont(KGlobalSettings::generalFont());
-        limit->setFont(KGlobalSettings::generalFont());
+        getTextView()->setFont(TDEGlobalSettings::generalFont());
+        topicLine->setFont(TDEGlobalSettings::generalFont());
+        channelInput->setFont(TDEGlobalSettings::generalFont());
+        nicknameCombobox->setFont(TDEGlobalSettings::generalFont());
+        limit->setFont(TDEGlobalSettings::generalFont());
     }
 
     nicknameListView->resort();
@@ -2305,7 +2305,7 @@ void Channel::updateAppearance()
     if (Preferences::customListFont())
         nicknameListView->setFont(Preferences::listFont());
     else
-        nicknameListView->setFont(KGlobalSettings::generalFont());
+        nicknameListView->setFont(TDEGlobalSettings::generalFont());
 
     nicknameListView->refresh();
 
@@ -2450,7 +2450,7 @@ void Channel::setAutoUserhost(bool state)
         {
             // re-add the hostmask column
             nicknameListView->addColumn(TQString());
-            nicknameListView->setColumnWidthMode(2,KListView::Maximum);
+            nicknameListView->setColumnWidthMode(2,TDEListView::Maximum);
             nicknameListView->setResizeMode(TQListView::NoColumn);
 
             // re-add already known hostmasks
@@ -2611,7 +2611,7 @@ void Channel::processPendingNicks()
     // Remove possible mode characters from nickname and store the resulting mode
     m_server->mangleNicknameWithModes(nickname, admin, owner, op, halfop, voice);
 
-    // TODO: make these an enumeration in KApplication or somewhere, we can use them as well
+    // TODO: make these an enumeration in TDEApplication or somewhere, we can use them as well
     unsigned int mode = (admin  ? 16 : 0) +
                         (owner  ?  8 : 0) +
                         (op     ?  4 : 0) +
